-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- If a copy of the bCDDL was not distributed with this
-- file, You can obtain one at http://beamng.com/bCDDL-1.1.txt

--Brake based skid-steer control logic for vehicles with multiple wheels per side
--Author : TrackpadUser using Stoat's tank controller for reference

local M = {}
M.type = "auxilliary"
M.relevantDevice = nil

--Wheel object
local rightWheels = {}
local leftWheels = {}

--Steering constants
local steerMaxFactor =  0.8
local brakeMaxFactor =  0.4

--Control variables
local leftBrake = 0
local rightBrake = 0
local steeringInput = 0
local brakeInput = 0
local prakingBrakeInput = 0
local dtcounter = 0

local function updateGFX(dt)
	--The "or 0" is to avoid issues when electrics returns "nil" values
	steeringInput = electrics.values.steering_input or 0
	brakeInput = electrics.values.brake or 0
	prakingBrakeInput = electrics.values.parkingbrake_input or 0


	--Right -> steering_input = 1      Left -> steering_input = -1
	leftBrake = math.min((math.min(0, steeringInput)*-1)*steerMaxFactor + brakeInput*brakeMaxFactor+ prakingBrakeInput*brakeMaxFactor,1)
	rightBrake = math.min(math.max(0, steeringInput)*steerMaxFactor + brakeInput*brakeMaxFactor + prakingBrakeInput*brakeMaxFactor,1)

	--Braking friction
	 for _,wheel in pairs(leftWheels) do
		wheel.desiredBrakingTorque = wheel.brakeTorque*leftBrake
	 end
	 for _,wheel in pairs(rightWheels) do
		wheel.desiredBrakingTorque = wheel.brakeTorque*rightBrake
	 end
	
	--if dtcounter == 60 then
	--	dtcounter = 0
	--	print(leftBrake)
	--	print(rightBrake)
	--else
	--	dtcounter = dtcounter+1
	--end
	
	

end

local function init(jbeamData)
	for _,wd in pairs(wheels.wheels) do
		if string.match(wd.name,"L") then table.insert(leftWheels, wd) end
		if string.match(wd.name,"R") then table.insert(rightWheels, wd) end
	end
end

M.init = init
M.reset = nop
M.updateGFX = updateGFX

return M